/*
	* OpmlCombine.aspx.cs
	* Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved. 
*/

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Web20Tools.Opml; 
using System.Reflection;
using System.Resources;   
using Web20Tools.Security;
using Web20Tools.ExceptionFramework;

namespace Samples.Opml
{
	/// <summary>
	/// Read multiple OPML Feeds and Aggregate into a single feed (filtered).
	/// </summary>
	public class OpmlCombine : System.Web.UI.Page
	{
        protected System.Web.UI.HtmlControls.HtmlForm Form1;
        protected System.Web.UI.WebControls.Label lblCreated;
        protected System.Web.UI.WebControls.HyperLink hlOpenXMLTop;
        protected System.Web.UI.WebControls.RadioButton rdddl;
        protected System.Web.UI.WebControls.DropDownList ddlUrls;
        protected System.Web.UI.WebControls.RadioButton rdtxt;
        protected System.Web.UI.WebControls.TextBox txtEnterUrl;
        protected System.Web.UI.WebControls.Button btnAddUrls;
        protected System.Web.UI.WebControls.Button btnRemove;
        protected System.Web.UI.WebControls.ListBox lbURL;
        protected System.Web.UI.WebControls.DropDownList ddlitem;
        protected System.Web.UI.WebControls.DropDownList ddloption;
        protected System.Web.UI.WebControls.TextBox txtKeyword;
        protected System.Web.UI.WebControls.Button btnAggregate;
        protected System.Web.UI.WebControls.Label lblMsg;
        protected System.Web.UI.WebControls.Label lblCreatedBottom;
        protected System.Web.UI.WebControls.HyperLink hlOpenXML;
		protected System.Web.UI.WebControls.TextBox txtHeadTitle;
		protected System.Web.UI.WebControls.TextBox txtHeadOwner;
        protected System.Web.UI.WebControls.HyperLink hlViewError;
        protected System.Web.UI.WebControls.Label lblError;

		private ResourceManager stringManager = new ResourceManager("Samples.SamplesResource",Assembly.GetExecutingAssembly()); 
	
		protected void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
			
			if(!IsPostBack) 
			{
				FillUrls(); 
				txtEnterUrl.Enabled = false;
				rdddl.Checked = true; 
				rdddl.Attributes.Add("OnClick","return EnableDisable();");
				rdtxt.Attributes.Add("OnClick","return EnableDisable();");
				txtHeadTitle.Text = stringManager.GetString("strOwner");
				txtHeadOwner.Text = stringManager.GetString("strOwner");
				btnAddUrls.Attributes.Add("OnClick","return AddUrls();");
				btnAggregate.Attributes.Add("OnClick","return Aggregate();");
                hlViewError.Attributes.Add("OnClick", "return ShowError();");
			}
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			
		}
		#endregion

		private void FillUrls()
		{
			ddlUrls.Items.Add(new ListItem(stringManager.GetString("strOpml10Url"), stringManager.GetString("strOpml10Url")) );
			ddlUrls.Items.Add(new ListItem(stringManager.GetString("strOpml20Url"), stringManager.GetString("strOpml20Url")) );

			ddlitem.Items.Add(new ListItem("Title","Title"));
			ddlitem.Items.Add(new ListItem("Description","Description"));

			ddloption.Items.Add(new ListItem("StartsWith","StartsWith") );
			ddloption.Items.Add(new ListItem("EndsWith","EndsWith") );
			ddloption.Items.Add(new ListItem("Contains","Contains") );
			ddloption.Items.Add(new ListItem("Equals","Equals") );
			ddloption.Items.Add(new ListItem("Not Equals","NotEquals") );

		}

		protected void btnAddUrls_Click(object sender, System.EventArgs e)
		{
			if(rdddl.Checked == true)
			{
				lbURL.Items.Add(ddlUrls.SelectedValue); 
				txtEnterUrl.Enabled = false;
				ddlUrls.Enabled = true;;
			}
			else if(rdtxt.Checked == true)
			{
                if (!txtEnterUrl.Text.ToUpper().StartsWith("http://".ToUpper()))
                    txtEnterUrl.Text = "http://" + txtEnterUrl.Text;
                
				lbURL.Items.Add(txtEnterUrl.Text);
				ddlUrls.Enabled = false;
				txtEnterUrl.Enabled = true;
				txtEnterUrl.Text = stringManager.GetString("strHttp");
			}
			
			lblMsg.Text = stringManager.GetString("strBlank");
			lblCreated.Text = stringManager.GetString("strBlank");
			lblCreatedBottom.Text = stringManager.GetString("strBlank");
			hlOpenXML.Text = stringManager.GetString("strBlank");
			hlOpenXMLTop.Text = stringManager.GetString("strBlank");
            hlViewError.Text = stringManager.GetString("strBlank");
		}

		private string FilterItem()
		{
			string filterentry = string.Empty; 
			switch(ddlitem.SelectedValue.ToLower())
			{
				case "title":
					filterentry = "title";
					break;
				case "description":
					filterentry = "description";
					break;
			}
			return filterentry; 
		}
				
		private string FilterOperation()
		{
			string filtertype = string.Empty; 
			switch(ddloption.SelectedValue.ToLower())
			{
				case "startswith":
					filtertype = "startswith";
					break;
				case "endswith":
					filtertype = "endswith";
					break;
				case "contains":
					filtertype = "contains";
					break;
				case "equals":
					filtertype = "equals";
					break;
				case "notequals":
					filtertype = "notequals";
					break;
			}
			return filtertype;
		}

		private void LoadFeeds()
		{
			try
			{
                License.LoadLicense();
				OpmlDoc doc = new OpmlDoc(); 
				
				doc.Version = "2.0";
				doc.Head.Title = txtHeadTitle.Text;
				doc.Head.OwnerName = txtHeadOwner.Text;
				doc.Head.DateCreated = DateTime.Now.ToString();     
  
				for(int i =0; i<lbURL.Items.Count; i++)
				{
					OpmlDoc tempdoc = OpmlDoc.Load(lbURL.Items[i].Value); 

                        foreach (Outline objOutline in tempdoc.Body.Outlines) 
						{
                            foreach (Outline objSubOutLine in objOutline.Outlines)
                            {
                                if (ApplyConstraint(objSubOutLine))
                                {
                                    doc.Body.Outlines.Add(objSubOutLine);
                                }
                            }
						}
				 }						

					if(doc.Body.Outlines.Count != 0 )
					{
						Session.Add("FeedShow",doc);
								
						lblCreated.Text = stringManager.GetString("strCreated"); 
						lblCreatedBottom.Text = stringManager.GetString("strCreated");
						hlOpenXML.Text = stringManager.GetString("strClick"); 
					
						hlOpenXMLTop.Text = stringManager.GetString("strClick");  
						hlOpenXML.NavigateUrl = "OpmlShowFeed.aspx";
						hlOpenXMLTop.NavigateUrl = "OpmlShowFeed.aspx"; 
						hlOpenXML.Target = "_blank";
						hlOpenXMLTop.Target = "_blank"; 
						lblMsg.Text = stringManager.GetString("strBlank");
					}
					else
					{
						lblCreated.Text = stringManager.GetString("strBlank");
						lblCreatedBottom.Text = stringManager.GetString("strBlank");
						hlOpenXML.Text = stringManager.GetString("strBlank");
						hlOpenXMLTop.Text = stringManager.GetString("strBlank");
						lblMsg.Text = stringManager.GetString("strNoMatch"); 
					}
                    hlViewError.Text = stringManager.GetString("strBlank");
                    hlViewError.NavigateUrl = stringManager.GetString("strBlank");
                    lblError.Text = stringManager.GetString("strBlank");				
			}
			catch (InvalidLicenseException ilex)
			{
				lblCreated.Text = stringManager.GetString("strBlank");
				lblCreatedBottom.Text = stringManager.GetString("strBlank");
				hlOpenXML.Text = stringManager.GetString("strBlank");
				hlOpenXMLTop.Text = stringManager.GetString("strBlank");

				lblMsg.Text = stringManager.GetString("strLicenseException");
				Session["FeedShow"] = null;

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = ilex.Message;
			}
            catch (InvalidLicenseInfoException iliex)
            {
                lblCreated.Text = stringManager.GetString("strBlank");
                lblCreatedBottom.Text = stringManager.GetString("strBlank");
                hlOpenXML.Text = stringManager.GetString("strBlank");
                hlOpenXMLTop.Text = stringManager.GetString("strBlank");

                lblMsg.Text = stringManager.GetString("strInvalidLicenseInfo");
                Session["FeedShow"] = null;

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = iliex.Message;
            }
			catch(Exception ex)
			{
				lblCreated.Text = stringManager.GetString("strBlank");
				lblCreatedBottom.Text = stringManager.GetString("strBlank");
				hlOpenXML.Text = stringManager.GetString("strBlank");
				hlOpenXMLTop.Text = stringManager.GetString("strBlank");
				
				lblMsg.Text = stringManager.GetString("strErrorCreating"); 
				Session["FeedShow"] = null;

                hlViewError.Text = stringManager.GetString("strViewError");
                hlViewError.NavigateUrl = "#";
                lblError.Text = ex.Message;
			}
			
		}

		private bool ApplyConstraint(Outline objOutline)
		{
			if(txtKeyword.Text.Length  == 0)
			{
				return true;
			}
			else
			{
				string item;
				string operation;
				
				item = FilterItem();
				operation = FilterOperation();
				
				if(item == "title")
				{
					if(objOutline.Title != null)
					{
						if(operation == "startswith")
						{
							if(objOutline.Title.ToLower().StartsWith(txtKeyword.Text.ToLower()))
								return true;
							else
								return false;
						}
						if(operation == "endswith")
						{
							if(objOutline.Title.ToLower().EndsWith(txtKeyword.Text.ToLower()))
								return true;
							else
								return false;
						}
						if(operation == "contains")
						{
							if(objOutline.Title.ToLower().IndexOf(txtKeyword.Text.ToLower()) == -1)
								return false;
							else
								return true;
						}
						if(operation == "equals")
						{
							if(string.Compare(objOutline.Title, txtKeyword.Text, true, System.Globalization.CultureInfo.CurrentCulture) == 0 )
								return true;
							else
								return false;
						}
						if(operation == "notequals")
						{
							if(string.Compare(objOutline.Title, txtKeyword.Text, true, System.Globalization.CultureInfo.CurrentCulture) == -1)
								return true;
							else
								return false;
						}
					}
				}

				if(item == "description")
				{
					if(objOutline.Text != null )
					{
						if(operation == "startswith")
						{
							if(objOutline.Description.ToLower().StartsWith(txtKeyword.Text.ToLower()))
								return true;
							else
								return false;
						}
						if(operation == "endswith")
						{
							if(objOutline.Description.ToLower().EndsWith(txtKeyword.Text.ToLower()))
								return true;
							else
								return false;
						}
						if(operation == "contains")
						{
							if(objOutline.Description.ToLower().IndexOf(txtKeyword.Text.ToLower()) == -1)
								return false;
							else
								return true;
						}
						if(operation == "equals")
						{
							if(string.Compare(objOutline.Description, txtKeyword.Text, true, System.Globalization.CultureInfo.CurrentCulture) == 0 )
								return true;
							else
								return false;
						}
						if(operation == "notequals")
						{
							if(string.Compare(objOutline.Description, txtKeyword.Text, true, System.Globalization.CultureInfo.CurrentCulture) == -1 )
								return true;
							else
								return false;
						}
					}
				}					
			}
			return false;
		}

		protected void btnAggregate_Click(object sender, System.EventArgs e)
		{
			LoadFeeds(); 		
		}

		protected void btnRemove_Click(object sender, System.EventArgs e)
		{
			if(lbURL.SelectedIndex > -1)
				lbURL.Items.Remove(lbURL.SelectedItem);    
			lblMsg.Text = stringManager.GetString("strBlank");
            lblCreated.Text = stringManager.GetString("strBlank");
            lblCreatedBottom.Text = stringManager.GetString("strBlank");
            hlOpenXML.Text = stringManager.GetString("strBlank");
            hlOpenXMLTop.Text = stringManager.GetString("strBlank");
            hlViewError.Text = stringManager.GetString("strBlank");
		}
	}
}
