/*
	* LoadOpml.cs
	* Copyright  2002 - 2008 ToolButton Inc. All Rights Reserved. 
*/
using System;
using System.Windows.Forms;
using Web20Tools.Opml;
using System.Reflection;
using System.Resources;
using Web20Tools.ExceptionFramework;
using Web20Tools.Security; 

namespace OpmlLoad
{
    public partial class LoadOpml : Form
    {
        OpmlDoc doc;
        ResourceManager stringManager = new ResourceManager("OpmlLoad.OpmlLoadResource", Assembly.GetExecutingAssembly());
        public LoadOpml()
        {
            InitializeComponent();
        }

        private void btnBrowse_Click(object sender, EventArgs e)
        {
            OpenFileDialog fupOpml = new OpenFileDialog();
            if (LoadRss_flg == false)
            {
                this.fupOpml.Reset();
                this.fupOpml.InitialDirectory = Environment.CurrentDirectory.Substring(0, (Environment.CurrentDirectory.ToString().IndexOf("bin", 0) - 1)); //Application.StartupPath;  //Path.GetFullPath("RssLoad");  //
                LoadRss_flg = true;
            }
            else
            {
                this.fupOpml.RestoreDirectory = true;
            }
            this.fupOpml.Filter = "(*.xml)|*.xml";
            
            if (this.fupOpml.ShowDialog() == DialogResult.OK)
            {
                txtData.Text = string.Empty;
                txtFile.Text = this.fupOpml.FileName;
            }           
        }

        private void btnLoad_Click(object sender, EventArgs e)
        {
            txtData.Text = string.Empty;
            OpmlDocument objDoc = new OpmlDocument();

            try
            {
                OpmlLicenseContext.LoadLicenseInfo("License Key", "License Owner");  
                if (rbtfile.Checked == true)
                {
                    if (ValidateFile())
                    {
                        doc = OpmlDoc.Load(fupOpml.FileName.ToString());
                    }
                }
                else if (rbturl.Checked == true)
                {
                    if (ValidateUrl())
                    {
                        doc = OpmlDoc.Load(txturl.Text.ToString());
                    }
                }
                else
                {
                    MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                    return;
                }
                txtData.Text = objDoc.DisplayDoc(doc);
            }
            catch (OpmlException ex)
            {
                if (ex.InnerException != null && ex.InnerException is InvalidLicenseException)
                {
                    LicenseMsgForm msgForm = new LicenseMsgForm();
                    msgForm.ShowDialog();
                    msgForm.Dispose();
                }
                else
                    MessageBox.Show(ex.Message, stringManager.GetString("strCaption")); 
            }
            catch (InvalidLicenseInfoException)
            {
                MessageBox.Show(stringManager.GetString("strInvalidLicenseInfo"), stringManager.GetString("strCaption"));
            }
            catch (InvalidLicenseException)
            {
                LicenseMsgForm msgForm = new LicenseMsgForm();
                msgForm.ShowDialog();
                msgForm.Dispose();
            }
            catch (Exception)
            {
                MessageBox.Show(stringManager.GetString("strFeedError"), stringManager.GetString("strCaption"));
            }       
        }

        public bool ValidateFile()
        {
            if (rbtfile.Checked == true && txtFile.Text.Length != 0)
            {
                if (!System.IO.File.Exists(txtFile.Text))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidFile"), stringManager.GetString("strCaption"));
                    return false;
                }
                return true;
            }
            else
            {
                return false;
            }
        }

        public bool ValidateUrl()
        {
            if (rbturl.Checked == true && txturl.Text.Length != 0)
            {
                if (!OpmlDocument.CheckUrl(txturl.Text))
                {
                    MessageBox.Show(stringManager.GetString("strInvalidUrl"), stringManager.GetString("strCaption"));
                    return false;
                }
                else
                {
                    return true;
                }
            }
            else
            {
                return false;
            }

        }

       
        private void btnSave_Click(object sender, EventArgs e)
        {
            txtData.Text = string.Empty;   
            try
            {
                SaveFileDialog saveOpmlFile = new SaveFileDialog();

                this.saveOpmlFile.Filter = "(*.xml)|*.xml";

                OpmlLicenseContext.LoadLicenseInfo("License Key", "License Owner");  
                if (this.saveOpmlFile.ShowDialog() == DialogResult.OK)
                {
                    if (rbtfile.Checked == true)
                    {
                        if (ValidateFile())
                        {
                            doc = OpmlDoc.Load(txtFile.Text.ToString());                         
                        }
                        else
                        {
                            MessageBox.Show(stringManager.GetString("strFile"), stringManager.GetString("strCaption"));
                            return;
                        }
                    }
                    else if (rbturl.Checked == true)
                    {
                        if (ValidateUrl())
                        {
                            doc = OpmlDoc.Load(txturl.Text.ToString());
                        }
                        else
                        {
                            MessageBox.Show(stringManager.GetString("strUrl"), stringManager.GetString("strCaption"));
                            return;
                        }
                    }
                    else
                    {
                        MessageBox.Show(stringManager.GetString("strSelect"), stringManager.GetString("strCaption"));
                        return;
                    }

                    try
                    {
                        doc.Save(this.saveOpmlFile.FileName.ToString());
                        MessageBox.Show(stringManager.GetString("strSuccess"), stringManager.GetString("strCaption"));  
                    }
                    catch (Exception)
                    {
                        MessageBox.Show(stringManager.GetString("strSaveError"), stringManager.GetString("strCaption"));
                        return;
                    }
                    
                    txturl.Text = string.Empty;
                    txtFile.Text = string.Empty;
                }
                LoadRss_flg  = true;

            }
            catch (Exception)
            {
                MessageBox.Show(stringManager.GetString("strXml"), stringManager.GetString("strCaption"));
                return;
            }
        }

        private void rbtfile_CheckedChanged(object sender, EventArgs e)
        {
            txturl.Text = string.Empty;
        }

        private void rbturl_CheckedChanged(object sender, EventArgs e)
        {
            txtFile.Text = string.Empty;
        }
    }
}